@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from asyncpy.spider import Spider,Request
+from asyncpy.spider import Spider
 
 
 class DemoSpider(Spider):
